[vlc-devel] [PATCH 2/4] libvlc: rename libvlc_video_direct3d_engine_d3d9

Steve Lhomme robux4 at ycbcr.xyz
Tue Feb 11 15:39:38 CET 2020


Use a similar name to the OpenGL engines
---
 doc/libvlc/d3d9_player.c          | 2 +-
 include/vlc/libvlc_media_player.h | 6 +++---
 lib/media_player.c                | 2 +-
 3 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/doc/libvlc/d3d9_player.c b/doc/libvlc/d3d9_player.c
index 4b925df52aa..e048d987ee0 100644
--- a/doc/libvlc/d3d9_player.c
+++ b/doc/libvlc/d3d9_player.c
@@ -376,7 +376,7 @@ int WINAPI WinMain(HINSTANCE hInstance,
     // DON'T use with callbacks libvlc_media_player_set_hwnd(p_mp, hWnd);
 
     /* Tell VLC to render into our D3D9 environment */
-    libvlc_video_set_output_callbacks( p_mp, libvlc_video_direct3d_engine_d3d9,
+    libvlc_video_set_output_callbacks( p_mp, libvlc_video_engine_d3d9,
                                        Setup_cb, Cleanup_cb, Resize_cb, UpdateOutput_cb, Swap_cb, StartRendering_cb,
                                        NULL, NULL, NULL,
                                        &Context );
diff --git a/lib/media_player.c b/lib/media_player.c
index fdb56c1c362..f68c5bf0c34 100644
--- a/lib/media_player.c
+++ b/lib/media_player.c
@@ -1067,7 +1067,7 @@ bool libvlc_video_set_output_callbacks(libvlc_media_player_t *mp,
         var_SetString ( mp, "vout", "direct3d11" );
         var_SetString ( mp, "dec-dev", "d3d11-device" );
     }
-    else if ( engine == libvlc_video_direct3d_engine_d3d9 )
+    else if ( engine == libvlc_video_engine_d3d9 )
     {
         var_SetString ( mp, "vout", "direct3d9" );
         var_SetString ( mp, "dec-dev", "d3d9-device" );
diff --git a/include/vlc/libvlc_media_player.h b/include/vlc/libvlc_media_player.h
index 38b1fc8d3c1..367463a70c8 100644
--- a/include/vlc/libvlc_media_player.h
+++ b/include/vlc/libvlc_media_player.h
@@ -529,7 +529,7 @@ typedef struct
  * \return true on success
  * \version LibVLC 4.0.0 or later
  *
  * For \ref libvlc_video_direct3d_engine_d3d9 the output must be a IDirect3D9*.
  * A reference to this object is held until the \ref LIBVLC_VIDEO_DEVICE_CLEANUP is called.
  * the device must be created with D3DPRESENT_PARAMETERS.hDeviceWindow set to 0.
  *
@@ -566,7 +566,7 @@ typedef struct
 {
     union {
         int dxgi_format;  /** the rendering DXGI_FORMAT for \ref libvlc_video_engine_d3d11*/
-        uint32_t d3d9_format;  /** the rendering D3DFORMAT for \ref libvlc_video_direct3d_engine_d3d9 */
+        uint32_t d3d9_format;  /** the rendering D3DFORMAT for \ref libvlc_video_engine_d3d9 */
         int opengl_format;  /** the rendering GLint GL_RGBA or GL_RGB for \ref libvlc_video_engine_opengl and
                             for \ref libvlc_video_engine_gles2 */
         void *p_surface; /** currently unused */
@@ -679,7 +679,7 @@ typedef enum libvlc_video_engine_t {
     /** Direct3D11 rendering engine */
     libvlc_video_engine_d3d11,
     /** Direct3D9 rendering engine */
-    libvlc_video_direct3d_engine_d3d9,
+    libvlc_video_engine_d3d9,
 } libvlc_video_engine_t;
 
 /** Set the callback to call when the host app resizes the rendering area.
@@ -529,7 +529,7 @@ typedef struct
  * \version LibVLC 4.0.0 or later
  *
- * For \ref libvlc_video_direct3d_engine_d3d9 the output must be a IDirect3D9*.
+ * For \ref libvlc_video_engine_d3d9 the output must be a IDirect3D9*.
  * A reference to this object is held until the \ref LIBVLC_VIDEO_DEVICE_CLEANUP is called.
  * the device must be created with D3DPRESENT_PARAMETERS.hDeviceWindow set to 0.
-- 
2.17.1



More information about the vlc-devel mailing list